@@ -25,7 +25,6 @@ from modusched.protocols import MsgType, full_client_request, receive_message
 from volcenginesdkarkruntime import Ark, AsyncArk
 
 
-
 class ArkClient:
     """
     ArkClient
@@ -46,7 +45,7 @@ class ArkClient:
         self.access_token = access_token or "rPnirNKqj-jYwic1yTYpVOUU0xx2g8uj"
         self.endpoint = "wss://openspeech.bytedance.com/api/v1/tts/ws_binary"
 
-    def product(self, data):
+    def request(self, data):
         result = self.client.chat.completions.create(**data)
         return result
     
@@ -64,11 +63,11 @@ class ArkClient:
         # before_sleep=before_sleep_log(logger, logging.INFO),  # 每次重试前打印日志
         reraise=True,  # 如果所有重试都失败，重新抛出最后一个异常
     )
-    async def aproduct(self, data):
+    async def arequest(self, data):
         result = await self.async_client.chat.completions.create(**data)
         return result
 
-    def product_stream(self, data):
+    def request_stream(self, data):
         stream = self.client.chat.completions.create(
             **data
         )
@@ -77,7 +76,7 @@ class ArkClient:
                 continue
             yield chunk.choices[0].delta.content
             
-    async def aproduct_stream(self, data):
+    async def arequest_stream(self, data):
         stream = await self.async_client.chat.completions.create(
             **data
         )
@@ -582,6 +581,13 @@ class OpenAIClient:
         return response.json()
 
 
+
+
+
+
+
+
+
 '''
 
 
