@@ -28,6 +28,7 @@ class Adapter():
         api_base: str = "https://api.bianxie.ai/v1/chat/completions",
         tools = [],
         system_prompt = "",
+        **kwargs,
     ):
         """初始化
         正常情况下, 这两个参数都不需要传入, 而是会自动寻找环境变量,除非要临时改变api_key.
@@ -37,15 +38,26 @@ class Adapter():
             api_base (str): Base URL for the API endpoint.
         """
         super().__init__()
+        """You are an expert researcher. Your job is to conduct thorough research and then write a polished report.
 
+        You have access to an internet search tool as your primary means of gathering information.
+
+        ## `add_func`
+
+        Use this to add two numbers.
+
+        ## `weather`
+
+        Use this to get the weather.
+        """
         self.model_name = model_name
         self.temperature = 0.1
         self.type = type
 
         if type == "openai":
-            self.client = OpenAIClient(api_key=api_key or os.getenv("BIANXIE_API_KEY"), api_base=api_base)
+            self.client = OpenAIClient(api_key=api_key or os.getenv("BIANXIE_API_KEY"), api_base=api_base,**kwargs)
         elif type == "ark":
-            self.client = ArkClient(api_key=api_key or os.getenv("ARK_API_KEY"))
+            self.client = ArkClient(api_key=api_key or os.getenv("ARK_API_KEY"),**kwargs)
         elif type == "agent":
             self.model = init_chat_model(
             model=f"openai:{model_name}",
@@ -55,18 +67,8 @@ class Adapter():
             self.agent = create_deep_agent(
                 model=self.model,
                 tools=tools,
-                system_prompt=system_prompt or """You are an expert researcher. Your job is to conduct thorough research and then write a polished report.
-
-    You have access to an internet search tool as your primary means of gathering information.
-
-    ## `add_func`
-
-    Use this to add two numbers.
-
-    ## `weather`
-
-    Use this to get the weather.
-    """
+                system_prompt=system_prompt,
+                **kwargs
             )
 
     def predict(self, 
@@ -809,7 +811,7 @@ class ArkAdapter(ModelAdapter):
             "temperature": self.temperature,
             **kwargs
         }
-        response = await self.client.aproduct(data)
+        response = await self.client.arequest(data)
 
         return response.choices[0].message.content
         # return self._deal_response(response=response)
